summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmcompositeobject.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmcompositeobject.h')
-rw-r--r--kpovmodeler/pmcompositeobject.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmcompositeobject.h b/kpovmodeler/pmcompositeobject.h
index 0d7ae6df..50298236 100644
--- a/kpovmodeler/pmcompositeobject.h
+++ b/kpovmodeler/pmcompositeobject.h
@@ -71,7 +71,7 @@ public:
* Returns true if the object contains the child object o
*/
virtual bool containsChild( PMObject* o ) const
- { return ( ( PMObject* )this == o->tqparent( ) ); }
+ { return ( ( PMObject* )this == o->parent( ) ); }
/**
* Returns the index of the object or -1 if not found
*/
@@ -135,7 +135,7 @@ public:
protected:
/**
* Adds num to the number of selected objects in this object and all
* tqparent objects. num can be negative.
*/
virtual void adjustSelectedChildren( int num );
@@ -135,7 +135,7 @@ public:
/**
* Adds num to the number of selected objects in this object and all
- * tqparent objects. num can be negative.
+ * parent objects. num can be negative.
*/
virtual void adjustSelectedChildren( int num );